from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.channel.v1 import channel_pb2 as _channel_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("channels", "acknowledgements", "commitments", "receipts", "send_sequences", "recv_sequences", "ack_sequences", "next_channel_sequence")
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    ACKNOWLEDGEMENTS_FIELD_NUMBER: _ClassVar[int]
    COMMITMENTS_FIELD_NUMBER: _ClassVar[int]
    RECEIPTS_FIELD_NUMBER: _ClassVar[int]
    SEND_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    RECV_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    ACK_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    NEXT_CHANNEL_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channels: _containers.RepeatedCompositeFieldContainer[_channel_pb2.IdentifiedChannel]
    acknowledgements: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    commitments: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    receipts: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    send_sequences: _containers.RepeatedCompositeFieldContainer[PacketSequence]
    recv_sequences: _containers.RepeatedCompositeFieldContainer[PacketSequence]
    ack_sequences: _containers.RepeatedCompositeFieldContainer[PacketSequence]
    next_channel_sequence: int
    def __init__(self, channels: _Optional[_Iterable[_Union[_channel_pb2.IdentifiedChannel, _Mapping]]] = ..., acknowledgements: _Optional[_Iterable[_Union[_channel_pb2.PacketState, _Mapping]]] = ..., commitments: _Optional[_Iterable[_Union[_channel_pb2.PacketState, _Mapping]]] = ..., receipts: _Optional[_Iterable[_Union[_channel_pb2.PacketState, _Mapping]]] = ..., send_sequences: _Optional[_Iterable[_Union[PacketSequence, _Mapping]]] = ..., recv_sequences: _Optional[_Iterable[_Union[PacketSequence, _Mapping]]] = ..., ack_sequences: _Optional[_Iterable[_Union[PacketSequence, _Mapping]]] = ..., next_channel_sequence: _Optional[int] = ...) -> None: ...

class PacketSequence(_message.Message):
    __slots__ = ("port_id", "channel_id", "sequence")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    sequence: int
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., sequence: _Optional[int] = ...) -> None: ...



from ibc.core.connection.v1 import connection_pb2 as _connection_pb2
from ibc.core.channel.v1 import channel_pb2 as _channel_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DATA_TYPE_UNINITIALIZED_UNSPECIFIED: _ClassVar[DataType]
    DATA_TYPE_CLIENT_STATE: _ClassVar[DataType]
    DATA_TYPE_CONSENSUS_STATE: _ClassVar[DataType]
    DATA_TYPE_CONNECTION_STATE: _ClassVar[DataType]
    DATA_TYPE_CHANNEL_STATE: _ClassVar[DataType]
    DATA_TYPE_PACKET_COMMITMENT: _ClassVar[DataType]
    DATA_TYPE_PACKET_ACKNOWLEDGEMENT: _ClassVar[DataType]
    DATA_TYPE_PACKET_RECEIPT_ABSENCE: _ClassVar[DataType]
    DATA_TYPE_NEXT_SEQUENCE_RECV: _ClassVar[DataType]
    DATA_TYPE_HEADER: _ClassVar[DataType]
DATA_TYPE_UNINITIALIZED_UNSPECIFIED: DataType
DATA_TYPE_CLIENT_STATE: DataType
DATA_TYPE_CONSENSUS_STATE: DataType
DATA_TYPE_CONNECTION_STATE: DataType
DATA_TYPE_CHANNEL_STATE: DataType
DATA_TYPE_PACKET_COMMITMENT: DataType
DATA_TYPE_PACKET_ACKNOWLEDGEMENT: DataType
DATA_TYPE_PACKET_RECEIPT_ABSENCE: DataType
DATA_TYPE_NEXT_SEQUENCE_RECV: DataType
DATA_TYPE_HEADER: DataType

class ClientState(_message.Message):
    __slots__ = ("sequence", "is_frozen", "consensus_state", "allow_update_after_proposal")
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    IS_FROZEN_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_UPDATE_AFTER_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    sequence: int
    is_frozen: bool
    consensus_state: ConsensusState
    allow_update_after_proposal: bool
    def __init__(self, sequence: _Optional[int] = ..., is_frozen: bool = ..., consensus_state: _Optional[_Union[ConsensusState, _Mapping]] = ..., allow_update_after_proposal: bool = ...) -> None: ...

class ConsensusState(_message.Message):
    __slots__ = ("public_key", "diversifier", "timestamp")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    DIVERSIFIER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    public_key: _any_pb2.Any
    diversifier: str
    timestamp: int
    def __init__(self, public_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., diversifier: _Optional[str] = ..., timestamp: _Optional[int] = ...) -> None: ...

class Header(_message.Message):
    __slots__ = ("sequence", "timestamp", "signature", "new_public_key", "new_diversifier")
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    NEW_PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    NEW_DIVERSIFIER_FIELD_NUMBER: _ClassVar[int]
    sequence: int
    timestamp: int
    signature: bytes
    new_public_key: _any_pb2.Any
    new_diversifier: str
    def __init__(self, sequence: _Optional[int] = ..., timestamp: _Optional[int] = ..., signature: _Optional[bytes] = ..., new_public_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., new_diversifier: _Optional[str] = ...) -> None: ...

class Misbehaviour(_message.Message):
    __slots__ = ("client_id", "sequence", "signature_one", "signature_two")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_ONE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_TWO_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    sequence: int
    signature_one: SignatureAndData
    signature_two: SignatureAndData
    def __init__(self, client_id: _Optional[str] = ..., sequence: _Optional[int] = ..., signature_one: _Optional[_Union[SignatureAndData, _Mapping]] = ..., signature_two: _Optional[_Union[SignatureAndData, _Mapping]] = ...) -> None: ...

class SignatureAndData(_message.Message):
    __slots__ = ("signature", "data_type", "data", "timestamp")
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    signature: bytes
    data_type: DataType
    data: bytes
    timestamp: int
    def __init__(self, signature: _Optional[bytes] = ..., data_type: _Optional[_Union[DataType, str]] = ..., data: _Optional[bytes] = ..., timestamp: _Optional[int] = ...) -> None: ...

class TimestampedSignatureData(_message.Message):
    __slots__ = ("signature_data", "timestamp")
    SIGNATURE_DATA_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    signature_data: bytes
    timestamp: int
    def __init__(self, signature_data: _Optional[bytes] = ..., timestamp: _Optional[int] = ...) -> None: ...

class SignBytes(_message.Message):
    __slots__ = ("sequence", "timestamp", "diversifier", "data_type", "data")
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DIVERSIFIER_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    sequence: int
    timestamp: int
    diversifier: str
    data_type: DataType
    data: bytes
    def __init__(self, sequence: _Optional[int] = ..., timestamp: _Optional[int] = ..., diversifier: _Optional[str] = ..., data_type: _Optional[_Union[DataType, str]] = ..., data: _Optional[bytes] = ...) -> None: ...

class HeaderData(_message.Message):
    __slots__ = ("new_pub_key", "new_diversifier")
    NEW_PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    NEW_DIVERSIFIER_FIELD_NUMBER: _ClassVar[int]
    new_pub_key: _any_pb2.Any
    new_diversifier: str
    def __init__(self, new_pub_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., new_diversifier: _Optional[str] = ...) -> None: ...

class ClientStateData(_message.Message):
    __slots__ = ("path", "client_state")
    PATH_FIELD_NUMBER: _ClassVar[int]
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    client_state: _any_pb2.Any
    def __init__(self, path: _Optional[bytes] = ..., client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ConsensusStateData(_message.Message):
    __slots__ = ("path", "consensus_state")
    PATH_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    consensus_state: _any_pb2.Any
    def __init__(self, path: _Optional[bytes] = ..., consensus_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ConnectionStateData(_message.Message):
    __slots__ = ("path", "connection")
    PATH_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    connection: _connection_pb2.ConnectionEnd
    def __init__(self, path: _Optional[bytes] = ..., connection: _Optional[_Union[_connection_pb2.ConnectionEnd, _Mapping]] = ...) -> None: ...

class ChannelStateData(_message.Message):
    __slots__ = ("path", "channel")
    PATH_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    channel: _channel_pb2.Channel
    def __init__(self, path: _Optional[bytes] = ..., channel: _Optional[_Union[_channel_pb2.Channel, _Mapping]] = ...) -> None: ...

class PacketCommitmentData(_message.Message):
    __slots__ = ("path", "commitment")
    PATH_FIELD_NUMBER: _ClassVar[int]
    COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    commitment: bytes
    def __init__(self, path: _Optional[bytes] = ..., commitment: _Optional[bytes] = ...) -> None: ...

class PacketAcknowledgementData(_message.Message):
    __slots__ = ("path", "acknowledgement")
    PATH_FIELD_NUMBER: _ClassVar[int]
    ACKNOWLEDGEMENT_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    acknowledgement: bytes
    def __init__(self, path: _Optional[bytes] = ..., acknowledgement: _Optional[bytes] = ...) -> None: ...

class PacketReceiptAbsenceData(_message.Message):
    __slots__ = ("path",)
    PATH_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    def __init__(self, path: _Optional[bytes] = ...) -> None: ...

class NextSequenceRecvData(_message.Message):
    __slots__ = ("path", "next_seq_recv")
    PATH_FIELD_NUMBER: _ClassVar[int]
    NEXT_SEQ_RECV_FIELD_NUMBER: _ClassVar[int]
    path: bytes
    next_seq_recv: int
    def __init__(self, path: _Optional[bytes] = ..., next_seq_recv: _Optional[int] = ...) -> None: ...



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.cosmos.slashing.v1beta1.query_pb2 import (
    QueryParamsResponse,
    QuerySigningInfoRequest,
    QuerySigningInfoResponse,
    QuerySigningInfosRequest,
    QuerySigningInfosResponse,
)
from neurionpy.slashing.interface import Slashing


class SlashingRestClient(Slashing):
    """Slashing REST client."""

    API_URL = "/cosmos/slashing/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Params(self) -> QueryParamsResponse:
        """
        Params queries the parameters of slashing module.

        :return: QueryParamsResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/params",
        )
        return Parse(json_response, QueryParamsResponse())

    def SigningInfo(self, request: QuerySigningInfoRequest) -> QuerySigningInfoResponse:
        """
        SigningInfo queries the signing info of given cons address.

        :param request: QuerySigningInfoRequest

        :return: QuerySigningInfoResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/signing_infos/{request.cons_address}",
        )
        return Parse(json_response, QuerySigningInfoResponse())

    def SigningInfos(
        self, request: QuerySigningInfosRequest
    ) -> QuerySigningInfosResponse:
        """
        SigningInfos queries signing info of all validators.

        :param request: QuerySigningInfosRequest

        :return: QuerySigningInfosResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/signing_infos", request)
        return Parse(json_response, QuerySigningInfosResponse())



from abc import ABC, abstractmethod

from neurionpy.protos.ibc.core.connection.v1.query_pb2 import (
    QueryClientConnectionsRequest,
    QueryClientConnectionsResponse,
    QueryConnectionClientStateRequest,
    QueryConnectionClientStateResponse,
    QueryConnectionConsensusStateRequest,
    QueryConnectionConsensusStateResponse,
    QueryConnectionRequest,
    QueryConnectionResponse,
    QueryConnectionsRequest,
    QueryConnectionsResponse,
)


class IBCCoreConnection(ABC):
    """IBC Core Connection abstract class."""

    @abstractmethod
    def Connection(self, request: QueryConnectionRequest) -> QueryConnectionResponse:
        """
        Connection queries an IBC connection end.

        :param request: QueryConnectionRequest
        :return: QueryConnectionResponse
        """  # noqa: D401

    @abstractmethod
    def Connections(self, request: QueryConnectionsRequest) -> QueryConnectionsResponse:
        """
        Connection queries all the IBC connections of a chain.

        :param request: QueryConnectionsRequest
        :return: QueryConnectionsResponse
        """  # noqa: D401

    @abstractmethod
    def ClientConnections(
        self, request: QueryClientConnectionsRequest
    ) -> QueryClientConnectionsResponse:
        """
        ClientConnection queries the connection paths associated with a client state.

        :param request: QueryClientConnectionsRequest
        :return: QueryClientConnectionsResponse
        """

    @abstractmethod
    def ConnectionClientState(
        self, request: QueryConnectionClientStateRequest
    ) -> QueryConnectionClientStateResponse:
        """
        ConnectionClientState queries the client state associated with the connection.

        :param request: QueryConnectionClientStateRequest
        :return: QueryConnectionClientStateResponse
        """

    @abstractmethod
    def ConnectionConsensusState(
        self, request: QueryConnectionConsensusStateRequest
    ) -> QueryConnectionConsensusStateResponse:
        """
        ConnectionConsensusState queries the consensus state associated with the connection.

        :param request: QueryConnectionConsensusStateRequest
        :return: QueryConnectionConsensusStateResponse
        """



from neurionpy.crypto.address import Address
from neurionpy.protos.cosmos.distribution.v1beta1.tx_pb2 import MsgWithdrawDelegatorReward


def create_withdraw_delegator_reward(delegator: Address, validator: Address):
    """Create withdraw delegator reward.

    :param delegator: delegator address
    :param validator: validator address
    :return: withdraw delegator reward message
    """
    return MsgWithdrawDelegatorReward(
        delegator_address=str(delegator),
        validator_address=str(validator),
    )



import re
from typing import List

from neurionpy.protos.cosmos.base.v1beta1.coin_pb2 import Coin


def parse_coins(value: str) -> List[Coin]:
    """Parse the coins.

    :param value: coins
    :raises RuntimeError: If unable to parse the value
    :return: coins
    """
    coins = []

    parts = re.split(r",\s*", value)
    for part in parts:
        part = part.strip()
        if part == "":
            continue

        match = re.match(r"^(\d+)(.+)$", part)
        if match is None:
            raise RuntimeError(f"Unable to parse value {part}")

        # extract out the groups
        amount, denom = match.groups()
        coins.append(Coin(amount=amount, denom=denom))

    return coins



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("host_enabled", "allow_messages")
    HOST_ENABLED_FIELD_NUMBER: _ClassVar[int]
    ALLOW_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    host_enabled: bool
    allow_messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, host_enabled: bool = ..., allow_messages: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmwasm/wasm/v1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmwasm/wasm/v1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from cosmwasm.wasm.v1 import tx_pb2 as cosmwasm_dot_wasm_dot_v1_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmwasm/wasm/v1/genesis.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x19\x63osmwasm/wasm/v1/tx.proto\"\xc1\x04\n\x0cGenesisState\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\x04\xc8\xde\x1f\x00\x12>\n\x05\x63odes\x18\x02 \x03(\x0b\x32\x16.cosmwasm.wasm.v1.CodeB\x17\xc8\xde\x1f\x00\xea\xde\x1f\x0f\x63odes,omitempty\x12J\n\tcontracts\x18\x03 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.ContractB\x1b\xc8\xde\x1f\x00\xea\xde\x1f\x13\x63ontracts,omitempty\x12J\n\tsequences\x18\x04 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.SequenceB\x1b\xc8\xde\x1f\x00\xea\xde\x1f\x13sequences,omitempty\x12T\n\x08gen_msgs\x18\x05 \x03(\x0b\x32&.cosmwasm.wasm.v1.GenesisState.GenMsgsB\x1a\xc8\xde\x1f\x00\xea\xde\x1f\x12gen_msgs,omitempty\x1a\xd2\x01\n\x07GenMsgs\x12\x34\n\nstore_code\x18\x01 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.MsgStoreCodeH\x00\x12H\n\x14instantiate_contract\x18\x02 \x01(\x0b\x32(.cosmwasm.wasm.v1.MsgInstantiateContractH\x00\x12@\n\x10\x65xecute_contract\x18\x03 \x01(\x0b\x32$.cosmwasm.wasm.v1.MsgExecuteContractH\x00\x42\x05\n\x03sum\"|\n\x04\x43ode\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x33\n\tcode_info\x18\x02 \x01(\x0b\x32\x1a.cosmwasm.wasm.v1.CodeInfoB\x04\xc8\xde\x1f\x00\x12\x12\n\ncode_bytes\x18\x03 \x01(\x0c\x12\x0e\n\x06pinned\x18\x04 \x01(\x08\"\x98\x01\n\x08\x43ontract\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12;\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\x04\xc8\xde\x1f\x00\x12\x35\n\x0e\x63ontract_state\x18\x03 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\x04\xc8\xde\x1f\x00\"4\n\x08Sequence\x12\x19\n\x06id_key\x18\x01 \x01(\x0c\x42\t\xe2\xde\x1f\x05IDKey\x12\r\n\x05value\x18\x02 \x01(\x04\x42(Z&github.com/CosmWasm/wasmd/x/wasm/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['codes']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['codes']._serialized_options = b'\310\336\037\000\352\336\037\017codes,omitempty'
  _globals['_GENESISSTATE'].fields_by_name['contracts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['contracts']._serialized_options = b'\310\336\037\000\352\336\037\023contracts,omitempty'
  _globals['_GENESISSTATE'].fields_by_name['sequences']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['sequences']._serialized_options = b'\310\336\037\000\352\336\037\023sequences,omitempty'
  _globals['_GENESISSTATE'].fields_by_name['gen_msgs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['gen_msgs']._serialized_options = b'\310\336\037\000\352\336\037\022gen_msgs,omitempty'
  _globals['_CODE'].fields_by_name['code_id']._loaded_options = None
  _globals['_CODE'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CODE'].fields_by_name['code_info']._loaded_options = None
  _globals['_CODE'].fields_by_name['code_info']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACT'].fields_by_name['contract_info']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_info']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACT'].fields_by_name['contract_state']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_state']._serialized_options = b'\310\336\037\000'
  _globals['_SEQUENCE'].fields_by_name['id_key']._loaded_options = None
  _globals['_SEQUENCE'].fields_by_name['id_key']._serialized_options = b'\342\336\037\005IDKey'
  _globals['_GENESISSTATE']._serialized_start=132
  _globals['_GENESISSTATE']._serialized_end=709
  _globals['_GENESISSTATE_GENMSGS']._serialized_start=499
  _globals['_GENESISSTATE_GENMSGS']._serialized_end=709
  _globals['_CODE']._serialized_start=711
  _globals['_CODE']._serialized_end=835
  _globals['_CONTRACT']._serialized_start=838
  _globals['_CONTRACT']._serialized_end=990
  _globals['_SEQUENCE']._serialized_start=992
  _globals['_SEQUENCE']._serialized_end=1044
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/abci/v1beta3/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/abci/v1beta3/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from cometbft.abci.v1beta2 import types_pb2 as cometbft_dot_abci_dot_v1beta2_dot_types__pb2
from cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2
from cometbft.types.v1beta1 import validator_pb2 as cometbft_dot_types_dot_v1beta1_dot_validator__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/abci/v1beta3/types.proto\x12\x15\x63ometbft.abci.v1beta3\x1a!cometbft/abci/v1beta1/types.proto\x1a!cometbft/abci/v1beta2/types.proto\x1a\x1e\x63ometbft/types/v1/params.proto\x1a&cometbft/types/v1beta1/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd2\x08\n\x07Request\x12\x32\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\".cometbft.abci.v1beta1.RequestEchoH\x00\x12\x34\n\x05\x66lush\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestFlushH\x00\x12\x32\n\x04info\x18\x03 \x01(\x0b\x32\".cometbft.abci.v1beta2.RequestInfoH\x00\x12=\n\ninit_chain\x18\x05 \x01(\x0b\x32\'.cometbft.abci.v1beta3.RequestInitChainH\x00\x12\x34\n\x05query\x18\x06 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestQueryH\x00\x12\x39\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32%.cometbft.abci.v1beta1.RequestCheckTxH\x00\x12\x36\n\x06\x63ommit\x18\x0b \x01(\x0b\x32$.cometbft.abci.v1beta1.RequestCommitH\x00\x12\x45\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestListSnapshotsH\x00\x12\x45\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestOfferSnapshotH\x00\x12N\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32/.cometbft.abci.v1beta1.RequestLoadSnapshotChunkH\x00\x12P\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunkH\x00\x12I\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32-.cometbft.abci.v1beta3.RequestPrepareProposalH\x00\x12I\n\x10process_proposal\x18\x11 \x01(\x0b\x32-.cometbft.abci.v1beta3.RequestProcessProposalH\x00\x12?\n\x0b\x65xtend_vote\x18\x12 \x01(\x0b\x32(.cometbft.abci.v1beta3.RequestExtendVoteH\x00\x12R\n\x15verify_vote_extension\x18\x13 \x01(\x0b\x32\x31.cometbft.abci.v1beta3.RequestVerifyVoteExtensionH\x00\x12\x45\n\x0e\x66inalize_block\x18\x14 \x01(\x0b\x32+.cometbft.abci.v1beta3.RequestFinalizeBlockH\x00\x42\x07\n\x05valueJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\x89\x02\n\x10RequestInitChain\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12<\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParams\x12@\n\nvalidators\x18\x04 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03\"\xc2\x02\n\x16RequestPrepareProposal\x12\x14\n\x0cmax_tx_bytes\x18\x01 \x01(\x03\x12\x0b\n\x03txs\x18\x02 \x03(\x0c\x12J\n\x11local_last_commit\x18\x03 \x01(\x0b\x32).cometbft.abci.v1beta3.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xb5\x02\n\x16RequestProcessProposal\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12\x45\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32!.cometbft.abci.v1beta3.CommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xb0\x02\n\x11RequestExtendVote\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x32\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x0b\n\x03txs\x18\x04 \x03(\x0c\x12\x45\n\x14proposed_last_commit\x18\x05 \x01(\x0b\x32!.cometbft.abci.v1beta3.CommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x0bmisbehavior\x18\x06 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"m\n\x1aRequestVerifyVoteExtension\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x16\n\x0evote_extension\x18\x04 \x01(\x0c\"\xb2\x02\n\x14RequestFinalizeBlock\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12\x44\n\x13\x64\x65\x63ided_last_commit\x18\x02 \x01(\x0b\x32!.cometbft.abci.v1beta3.CommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xa2\t\n\x08Response\x12=\n\texception\x18\x01 \x01(\x0b\x32(.cometbft.abci.v1beta1.ResponseExceptionH\x00\x12\x33\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseEchoH\x00\x12\x35\n\x05\x66lush\x18\x03 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseFlushH\x00\x12\x33\n\x04info\x18\x04 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseInfoH\x00\x12>\n\ninit_chain\x18\x06 \x01(\x0b\x32(.cometbft.abci.v1beta3.ResponseInitChainH\x00\x12\x35\n\x05query\x18\x07 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseQueryH\x00\x12:\n\x08\x63heck_tx\x18\t \x01(\x0b\x32&.cometbft.abci.v1beta3.ResponseCheckTxH\x00\x12\x37\n\x06\x63ommit\x18\x0c \x01(\x0b\x32%.cometbft.abci.v1beta3.ResponseCommitH\x00\x12\x46\n\x0elist_snapshots\x18\r \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseListSnapshotsH\x00\x12\x46\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseOfferSnapshotH\x00\x12O\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunkH\x00\x12Q\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunkH\x00\x12J\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponsePrepareProposalH\x00\x12J\n\x10process_proposal\x18\x12 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponseProcessProposalH\x00\x12@\n\x0b\x65xtend_vote\x18\x13 \x01(\x0b\x32).cometbft.abci.v1beta3.ResponseExtendVoteH\x00\x12S\n\x15verify_vote_extension\x18\x14 \x01(\x0b\x32\x32.cometbft.abci.v1beta3.ResponseVerifyVoteExtensionH\x00\x12\x46\n\x0e\x66inalize_block\x18\x15 \x01(\x0b\x32,.cometbft.abci.v1beta3.ResponseFinalizeBlockH\x00\x42\x07\n\x05valueJ\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"\xa5\x01\n\x11ResponseInitChain\x12<\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParams\x12@\n\nvalidators\x18\x02 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\x0c\"\x86\x02\n\x0fResponseCheckTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12\x46\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\tJ\x04\x08\t\x10\x0cR\x06senderR\x08priorityR\rmempool_error\"3\n\x0eResponseCommit\x12\x15\n\rretain_height\x18\x03 \x01(\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\",\n\x12ResponseExtendVote\x12\x16\n\x0evote_extension\x18\x01 \x01(\x0c\"\xa3\x01\n\x1bResponseVerifyVoteExtension\x12O\n\x06status\x18\x01 \x01(\x0e\x32?.cometbft.abci.v1beta3.ResponseVerifyVoteExtension.VerifyStatus\"3\n\x0cVerifyStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02\"\xb8\x02\n\x15ResponseFinalizeBlock\x12\x46\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x37\n\ntx_results\x18\x02 \x03(\x0b\x32#.cometbft.abci.v1beta3.ExecTxResult\x12G\n\x11validator_updates\x18\x03 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x43\n\x17\x63onsensus_param_updates\x18\x04 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParams\x12\x10\n\x08\x61pp_hash\x18\x05 \x01(\x0c\"\x87\x01\n\x08VoteInfo\x12\x39\n\tvalidator\x18\x01 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12:\n\rblock_id_flag\x18\x03 \x01(\x0e\x32#.cometbft.types.v1beta1.BlockIDFlagJ\x04\x08\x02\x10\x03\"\xc4\x01\n\x10\x45xtendedVoteInfo\x12\x39\n\tvalidator\x18\x01 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12\x16\n\x0evote_extension\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\x04 \x01(\x0c\x12:\n\rblock_id_flag\x18\x05 \x01(\x0e\x32#.cometbft.types.v1beta1.BlockIDFlagJ\x04\x08\x02\x10\x03\"Q\n\nCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12\x34\n\x05votes\x18\x02 \x03(\x0b\x32\x1f.cometbft.abci.v1beta3.VoteInfoB\x04\xc8\xde\x1f\x00\"a\n\x12\x45xtendedCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12<\n\x05votes\x18\x02 \x03(\x0b\x32\'.cometbft.abci.v1beta3.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00\"\xdc\x01\n\x0c\x45xecTxResult\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12\x46\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"p\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x12\x39\n\x06result\x18\x04 \x01(\x0b\x32#.cometbft.abci.v1beta3.ExecTxResultB\x04\xc8\xde\x1f\x00\x32\xdd\x0c\n\x04\x41\x42\x43I\x12O\n\x04\x45\x63ho\x12\".cometbft.abci.v1beta1.RequestEcho\x1a#.cometbft.abci.v1beta1.ResponseEcho\x12R\n\x05\x46lush\x12#.cometbft.abci.v1beta1.RequestFlush\x1a$.cometbft.abci.v1beta1.ResponseFlush\x12O\n\x04Info\x12\".cometbft.abci.v1beta2.RequestInfo\x1a#.cometbft.abci.v1beta1.ResponseInfo\x12X\n\x07\x43heckTx\x12%.cometbft.abci.v1beta1.RequestCheckTx\x1a&.cometbft.abci.v1beta3.ResponseCheckTx\x12R\n\x05Query\x12#.cometbft.abci.v1beta1.RequestQuery\x1a$.cometbft.abci.v1beta1.ResponseQuery\x12U\n\x06\x43ommit\x12$.cometbft.abci.v1beta1.RequestCommit\x1a%.cometbft.abci.v1beta3.ResponseCommit\x12^\n\tInitChain\x12\'.cometbft.abci.v1beta3.RequestInitChain\x1a(.cometbft.abci.v1beta3.ResponseInitChain\x12j\n\rListSnapshots\x12+.cometbft.abci.v1beta1.RequestListSnapshots\x1a,.cometbft.abci.v1beta1.ResponseListSnapshots\x12j\n\rOfferSnapshot\x12+.cometbft.abci.v1beta1.RequestOfferSnapshot\x1a,.cometbft.abci.v1beta1.ResponseOfferSnapshot\x12v\n\x11LoadSnapshotChunk\x12/.cometbft.abci.v1beta1.RequestLoadSnapshotChunk\x1a\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunk\x12y\n\x12\x41pplySnapshotChunk\x12\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunk\x1a\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunk\x12p\n\x0fPrepareProposal\x12-.cometbft.abci.v1beta3.RequestPrepareProposal\x1a..cometbft.abci.v1beta2.ResponsePrepareProposal\x12p\n\x0fProcessProposal\x12-.cometbft.abci.v1beta3.RequestProcessProposal\x1a..cometbft.abci.v1beta2.ResponseProcessProposal\x12\x61\n\nExtendVote\x12(.cometbft.abci.v1beta3.RequestExtendVote\x1a).cometbft.abci.v1beta3.ResponseExtendVote\x12|\n\x13VerifyVoteExtension\x12\x31.cometbft.abci.v1beta3.RequestVerifyVoteExtension\x1a\x32.cometbft.abci.v1beta3.ResponseVerifyVoteExtension\x12j\n\rFinalizeBlock\x12+.cometbft.abci.v1beta3.RequestFinalizeBlock\x1a,.cometbft.abci.v1beta3.ResponseFinalizeBlockB8Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v1beta3.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta3'
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTEXTENDVOTE'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['decided_last_commit']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['decided_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTFINALIZEBLOCK'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEFINALIZEBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_VOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_VOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXECTXRESULT'].fields_by_name['events']._loaded_options = None
  _globals['_EXECTXRESULT'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_TXRESULT'].fields_by_name['result']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _globals['_REQUEST']._serialized_start=258
  _globals['_REQUEST']._serialized_end=1364
  _globals['_REQUESTINITCHAIN']._serialized_start=1367
  _globals['_REQUESTINITCHAIN']._serialized_end=1632
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_start=1635
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_end=1957
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_start=1960
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_end=2269
  _globals['_REQUESTEXTENDVOTE']._serialized_start=2272
  _globals['_REQUESTEXTENDVOTE']._serialized_end=2576
  _globals['_REQUESTVERIFYVOTEEXTENSION']._serialized_start=2578
  _globals['_REQUESTVERIFYVOTEEXTENSION']._serialized_end=2687
  _globals['_REQUESTFINALIZEBLOCK']._serialized_start=2690
  _globals['_REQUESTFINALIZEBLOCK']._serialized_end=2996
  _globals['_RESPONSE']._serialized_start=2999
  _globals['_RESPONSE']._serialized_end=4185
  _globals['_RESPONSEINITCHAIN']._serialized_start=4188
  _globals['_RESPONSEINITCHAIN']._serialized_end=4353
  _globals['_RESPONSECHECKTX']._serialized_start=4356
  _globals['_RESPONSECHECKTX']._serialized_end=4618
  _globals['_RESPONSECOMMIT']._serialized_start=4620
  _globals['_RESPONSECOMMIT']._serialized_end=4671
  _globals['_RESPONSEEXTENDVOTE']._serialized_start=4673
  _globals['_RESPONSEEXTENDVOTE']._serialized_end=4717
  _globals['_RESPONSEVERIFYVOTEEXTENSION']._serialized_start=4720
  _globals['_RESPONSEVERIFYVOTEEXTENSION']._serialized_end=4883
  _globals['_RESPONSEVERIFYVOTEEXTENSION_VERIFYSTATUS']._serialized_start=4832
  _globals['_RESPONSEVERIFYVOTEEXTENSION_VERIFYSTATUS']._serialized_end=4883
  _globals['_RESPONSEFINALIZEBLOCK']._serialized_start=4886
  _globals['_RESPONSEFINALIZEBLOCK']._serialized_end=5198
  _globals['_VOTEINFO']._serialized_start=5201
  _globals['_VOTEINFO']._serialized_end=5336
  _globals['_EXTENDEDVOTEINFO']._serialized_start=5339
  _globals['_EXTENDEDVOTEINFO']._serialized_end=5535
  _globals['_COMMITINFO']._serialized_start=5537
  _globals['_COMMITINFO']._serialized_end=5618
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=5620
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=5717
  _globals['_EXECTXRESULT']._serialized_start=5720
  _globals['_EXECTXRESULT']._serialized_end=5940
  _globals['_TXRESULT']._serialized_start=5942
  _globals['_TXRESULT']._serialized_end=6054
  _globals['_ABCI']._serialized_start=6057
  _globals['_ABCI']._serialized_end=7686
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod


class Signer(ABC):
    """Signer abstract class."""

    @abstractmethod
    def sign(
        self, message: bytes, deterministic: bool = False, canonicalise: bool = True
    ) -> bytes:
        """
        Perform signing.

        :param message: bytes to sign
        :param deterministic: bool, default false
        :param canonicalise: bool,default True
        """

    @abstractmethod
    def sign_digest(
        self, digest: bytes, deterministic=False, canonicalise: bool = True
    ) -> bytes:
        """
        Perform digest signing.

        :param digest: bytes to sign
        :param deterministic: bool, default false
        :param canonicalise: bool,default True
        """



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Pathway(_message.Message):
    __slots__ = ("id", "creator", "name", "description", "is_public", "ions", "fee_per_thousand_calls", "field_maps", "stake")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    IONS_FIELD_NUMBER: _ClassVar[int]
    FEE_PER_THOUSAND_CALLS_FIELD_NUMBER: _ClassVar[int]
    FIELD_MAPS_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    name: str
    description: str
    is_public: bool
    ions: _containers.RepeatedScalarFieldContainer[str]
    fee_per_thousand_calls: int
    field_maps: _containers.RepeatedScalarFieldContainer[str]
    stake: int
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., is_public: bool = ..., ions: _Optional[_Iterable[str]] = ..., fee_per_thousand_calls: _Optional[int] = ..., field_maps: _Optional[_Iterable[str]] = ..., stake: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crypto/ed25519/keys.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/crypto/ed25519/keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/crypto/ed25519/keys.proto\x12\x15\x63osmos.crypto.ed25519\x1a\x14gogoproto/gogo.proto\"9\n\x06PubKey\x12)\n\x03key\x18\x01 \x01(\x0c\x42\x1c\xfa\xde\x1f\x18\x63rypto/ed25519.PublicKey:\x04\x98\xa0\x1f\x00\"5\n\x07PrivKey\x12*\n\x03key\x18\x01 \x01(\x0c\x42\x1d\xfa\xde\x1f\x19\x63rypto/ed25519.PrivateKeyB2Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.ed25519.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519'
  _globals['_PUBKEY'].fields_by_name['key']._loaded_options = None
  _globals['_PUBKEY'].fields_by_name['key']._serialized_options = b'\372\336\037\030crypto/ed25519.PublicKey'
  _globals['_PUBKEY']._loaded_options = None
  _globals['_PUBKEY']._serialized_options = b'\230\240\037\000'
  _globals['_PRIVKEY'].fields_by_name['key']._loaded_options = None
  _globals['_PRIVKEY'].fields_by_name['key']._serialized_options = b'\372\336\037\031crypto/ed25519.PrivateKey'
  _globals['_PUBKEY']._serialized_start=81
  _globals['_PUBKEY']._serialized_end=138
  _globals['_PRIVKEY']._serialized_start=140
  _globals['_PRIVKEY']._serialized_end=193
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgSubmitEvidence(_message.Message):
    __slots__ = ("submitter", "evidence")
    SUBMITTER_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    submitter: str
    evidence: _any_pb2.Any
    def __init__(self, submitter: _Optional[str] = ..., evidence: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class MsgSubmitEvidenceResponse(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    def __init__(self, hash: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/dispute_validation_task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/dispute_validation_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,neurion/fusion/dispute_validation_task.proto\x12\x0eneurion.fusion\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x81\x03\n\x15\x44isputeValidationTask\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\x19\n\x11proposed_model_id\x18\x03 \x01(\x04\x12N\n\x0eproposed_score\x18\x04 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12\x0f\n\x07\x64\x65posit\x18\x05 \x01(\x04\x12;\n\x06result\x18\x06 \x01(\x0e\x32+.neurion.fusion.DisputeValidationTaskResult\x12\x19\n\x11\x63reated_timestamp\x18\x07 \x01(\x04\x12\x1a\n\x12\x64\x65\x63ision_timestamp\x18\x08 \x01(\x04\x12$\n\x1c\x61\x63\x63\x65pting_dispute_validators\x18\t \x03(\t\x12$\n\x1crejecting_dispute_validators\x18\n \x03(\t\x12\x0f\n\x07task_id\x18\x0b \x01(\x04*\xa9\x01\n\x1b\x44isputeValidationTaskResult\x12\x30\n,DISPUTE_VALIDATION_TASK_RESULT_NOT_AVAILABLE\x10\x00\x12+\n\'DISPUTE_VALIDATION_TASK_RESULT_ACCEPTED\x10\x01\x12+\n\'DISPUTE_VALIDATION_TASK_RESULT_REJECTED\x10\x02\x42\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.dispute_validation_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_DISPUTEVALIDATIONTASK'].fields_by_name['proposed_score']._loaded_options = None
  _globals['_DISPUTEVALIDATIONTASK'].fields_by_name['proposed_score']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_DISPUTEVALIDATIONTASKRESULT']._serialized_start=521
  _globals['_DISPUTEVALIDATIONTASKRESULT']._serialized_end=690
  _globals['_DISPUTEVALIDATIONTASK']._serialized_start=133
  _globals['_DISPUTEVALIDATIONTASK']._serialized_end=518
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MsgIBCSend(_message.Message):
    __slots__ = ("channel", "timeout_height", "timeout_timestamp", "data")
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    channel: str
    timeout_height: int
    timeout_timestamp: int
    data: bytes
    def __init__(self, channel: _Optional[str] = ..., timeout_height: _Optional[int] = ..., timeout_timestamp: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class MsgIBCCloseChannel(_message.Message):
    __slots__ = ("channel",)
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    channel: str
    def __init__(self, channel: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/abci/v1/service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/abci/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ometbft/abci/v1/service.proto\x12\x10\x63ometbft.abci.v1\x1a\x1c\x63ometbft/abci/v1/types.proto2\xc4\x0b\n\x0b\x41\x42\x43IService\x12\x45\n\x04\x45\x63ho\x12\x1d.cometbft.abci.v1.EchoRequest\x1a\x1e.cometbft.abci.v1.EchoResponse\x12H\n\x05\x46lush\x12\x1e.cometbft.abci.v1.FlushRequest\x1a\x1f.cometbft.abci.v1.FlushResponse\x12\x45\n\x04Info\x12\x1d.cometbft.abci.v1.InfoRequest\x1a\x1e.cometbft.abci.v1.InfoResponse\x12N\n\x07\x43heckTx\x12 .cometbft.abci.v1.CheckTxRequest\x1a!.cometbft.abci.v1.CheckTxResponse\x12H\n\x05Query\x12\x1e.cometbft.abci.v1.QueryRequest\x1a\x1f.cometbft.abci.v1.QueryResponse\x12K\n\x06\x43ommit\x12\x1f.cometbft.abci.v1.CommitRequest\x1a .cometbft.abci.v1.CommitResponse\x12T\n\tInitChain\x12\".cometbft.abci.v1.InitChainRequest\x1a#.cometbft.abci.v1.InitChainResponse\x12`\n\rListSnapshots\x12&.cometbft.abci.v1.ListSnapshotsRequest\x1a\'.cometbft.abci.v1.ListSnapshotsResponse\x12`\n\rOfferSnapshot\x12&.cometbft.abci.v1.OfferSnapshotRequest\x1a\'.cometbft.abci.v1.OfferSnapshotResponse\x12l\n\x11LoadSnapshotChunk\x12*.cometbft.abci.v1.LoadSnapshotChunkRequest\x1a+.cometbft.abci.v1.LoadSnapshotChunkResponse\x12o\n\x12\x41pplySnapshotChunk\x12+.cometbft.abci.v1.ApplySnapshotChunkRequest\x1a,.cometbft.abci.v1.ApplySnapshotChunkResponse\x12\x66\n\x0fPrepareProposal\x12(.cometbft.abci.v1.PrepareProposalRequest\x1a).cometbft.abci.v1.PrepareProposalResponse\x12\x66\n\x0fProcessProposal\x12(.cometbft.abci.v1.ProcessProposalRequest\x1a).cometbft.abci.v1.ProcessProposalResponse\x12W\n\nExtendVote\x12#.cometbft.abci.v1.ExtendVoteRequest\x1a$.cometbft.abci.v1.ExtendVoteResponse\x12r\n\x13VerifyVoteExtension\x12,.cometbft.abci.v1.VerifyVoteExtensionRequest\x1a-.cometbft.abci.v1.VerifyVoteExtensionResponse\x12`\n\rFinalizeBlock\x12&.cometbft.abci.v1.FinalizeBlockRequest\x1a\'.cometbft.abci.v1.FinalizeBlockResponseB3Z1github.com/cometbft/cometbft/api/cometbft/abci/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cometbft/cometbft/api/cometbft/abci/v1'
  _globals['_ABCISERVICE']._serialized_start=83
  _globals['_ABCISERVICE']._serialized_end=1559
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/mint/v1beta1/mint.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/mint/v1beta1/mint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/mint/v1beta1/mint.proto\x12\x13\x63osmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\"\xb2\x01\n\x06Minter\x12\x41\n\tinflation\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x65\n\x11\x61nnual_provisions\x18\x02 \x01(\tBJ\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x18yaml:\"annual_provisions\"\"\xb8\x01\n\x06Params\x12\x12\n\nmint_denom\x18\x01 \x01(\t\x12_\n\x0einflation_rate\x18\x02 \x01(\tBG\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x15yaml:\"inflation_rate\"\x12\x33\n\x0f\x62locks_per_year\x18\x06 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"blocks_per_year\":\x04\x98\xa0\x1f\x00\x42+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.mint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
  _globals['_MINTER'].fields_by_name['inflation']._loaded_options = None
  _globals['_MINTER'].fields_by_name['inflation']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_MINTER'].fields_by_name['annual_provisions']._loaded_options = None
  _globals['_MINTER'].fields_by_name['annual_provisions']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\030yaml:\"annual_provisions\"'
  _globals['_PARAMS'].fields_by_name['inflation_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['inflation_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\025yaml:\"inflation_rate\"'
  _globals['_PARAMS'].fields_by_name['blocks_per_year']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['blocks_per_year']._serialized_options = b'\362\336\037\026yaml:\"blocks_per_year\"'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\230\240\037\000'
  _globals['_MINTER']._serialized_start=78
  _globals['_MINTER']._serialized_end=256
  _globals['_PARAMS']._serialized_start=259
  _globals['_PARAMS']._serialized_end=443
# @@protoc_insertion_point(module_scope)



import hashlib
import hmac
import os
import re
from typing import List, Optional, Tuple

from neurionpy.crypto.hashfuncs import sha256
from neurionpy.crypto.keypairs import PrivateKey
from neurionpy.mnemonic.words import ENGLISH_MNEMONIC_WORDS, ENGLISH_MNEMONIC_WORDS_LIST


SEED_MIN_BYTE_LEN = 16
HMAC_LEN = hashlib.sha512().digest_size
HMAC_HALF_LEN = HMAC_LEN // 2
MNEMONIC_SALT = "mnemonic"
MNEMONIC_ROUNDS = 2048
COSMOS_HD_PATH = "m/44'/118'/0'/0/0"


def split_hmac(data: bytes) -> Tuple[bytes, bytes]:
    """
    Split HMAC data into two halves.

    :param data: bytes
    :return: Tuple[bytes, bytes]
    """
    assert len(data) == HMAC_LEN
    return data[:HMAC_HALF_LEN], data[HMAC_HALF_LEN:]


def validate_private_key(private_key: bytes) -> bool:
    """
    Validate the private key.

    :param private_key: bytes
    :return: bool
    """
    try:
        PrivateKey(private_key)
        return True
    except RuntimeError:
        return False


def derive_master_key(seed_bytes: bytes) -> Tuple[bytes, bytes]:
    """
    Derive the master key and chain code from the seed bytes.

    :param seed_bytes: bytes
    :return: Tuple[bytes, bytes]
    :raises ValueError: If the seed length is invalid.
    """
    if len(seed_bytes) < SEED_MIN_BYTE_LEN:
        raise ValueError(f"Invalid seed length ({len(seed_bytes)})")

    # Compute HMAC, retry if the resulting private key is not valid
    hmac_out = b""
    hmac_data = seed_bytes
    success = False

    while not success:
        hmac_out = hmac.digest(b"Bitcoin seed", hmac_data, "sha512")

        if validate_private_key(hmac_out[:HMAC_HALF_LEN]):
            break

        hmac_data = hmac_out

    return split_hmac(hmac_out)


def parse_derivation_path(path: str) -> List[int]:
    """
    Parse the derivation path in the form of m/44'/118'/0'/0/0 and return a list of indexes.

    :param path: str
    :return: List[int]
    :raises RuntimeError: If the derivation path is invalid.
    """
    match = re.match(
        r"^m/(\d{1,3}'?)/(\d{1,3}'?)/(\d{1,3}'?)/(\d{1,3}'?)/(\d{1,3}'?)", path
    )
    if match is None:
        raise RuntimeError("Invalid derivation path")

    indexes: List[int] = []
    for i in range(1, 6):
        if match.group(i).endswith("'"):
            value = int(match.group(i)[:-1]) | (1 << 31)
        else:
            value = int(match.group(i))

        indexes.append(value)

    return indexes


def derive_child_key_from_index(
    private_key: bytes, chain_code: bytes, index: int
) -> Tuple[bytes, bytes]:
    """
    Derive a child key from the specified private key, chain code, and index.

    :param private_key: bytes
    :param chain_code: bytes
    :param index: int
    :return: Tuple[bytes, bytes]
    """
    parsed_private_key = PrivateKey(private_key)
    public_key = parsed_private_key.public_key.public_key_bytes

    is_hardened = index & (1 << 31)

    if is_hardened:
        data_bytes = b"\x00" + private_key + index.to_bytes(4, "big")
    else:
        data_bytes = public_key + index.to_bytes(4, "big")

    il_bytes, ir_bytes = split_hmac(hmac.digest(chain_code, data_bytes, "sha512"))

    # Construct new key secret from iL and current private key
    il_int = int.from_bytes(il_bytes, byteorder="big", signed=False)
    private_key_int = int.from_bytes(private_key, byteorder="big", signed=False)

    new_private_key_int = (il_int + private_key_int) % parsed_private_key.curve.order
    new_private_key_bytes = new_private_key_int.to_bytes(32, "big")

    return new_private_key_bytes, ir_bytes


def derive_child_key(master_private_key: bytes, chain_code: bytes, path: str) -> bytes:
    """
    Derive a child key from a master key and a derivation path.

    :param master_private_key: bytes The master private key.
    :param chain_code: bytes The chain code.
    :param path: str The derivation path.
    :return: bytes The derived child key.
    """
    indexes = parse_derivation_path(path)

    child_private_key = master_private_key
    for index in indexes:
        child_private_key, chain_code = derive_child_key_from_index(
            child_private_key, chain_code, index
        )

    return child_private_key


def validate_mnemonic_and_normalise(mnemonic: str) -> str:
    """
    Validate a mnemonic phrase.

    :param mnemonic: str The mnemonic phrase to validate.
    :return: str The normalized mnemonic phrase.

    :raises ValueError: If the mnemonic length is invalid or a word is invalid.
    """
    words = mnemonic.split()
    if len(words) not in [12, 15, 18, 21, 24]:
        raise ValueError("Invalid mnemonic length")

    for word in words:
        if word not in ENGLISH_MNEMONIC_WORDS:
            raise ValueError(f"Invalid mnemonic word: {word}")

    return " ".join(words)


def derive_seed_from_mnemonic(mnemonic: str, passphrase: Optional[str] = None) -> bytes:
    """
    Derive a seed from a mnemonic phrase.

    :param mnemonic: str The mnemonic phrase.
    :param passphrase: Optional[str] An optional passphrase.

    :return: bytes The derived seed as bytes.
    """
    # ensure that the mnemonic is valid
    mnemonic = validate_mnemonic_and_normalise(mnemonic)

    salt = MNEMONIC_SALT + (passphrase or "")
    return hashlib.pbkdf2_hmac(
        "sha512", mnemonic.encode(), salt.encode(), MNEMONIC_ROUNDS
    )


def derive_child_key_from_mnemonic(
    mnemonic: str,
    passphrase: Optional[str] = None,
    path: str = COSMOS_HD_PATH,
) -> bytes:
    """
    Derive a child key from a mnemonic phrase and a derivation path.

    :param mnemonic: str The mnemonic phrase.
    :param passphrase: Optional[str] An optional passphrase.
    :param path: str The derivation path.

    :return: bytes The derived child key.
    """
    # compute the seed bytes from the mnemonic
    seed_bytes = derive_seed_from_mnemonic(mnemonic, passphrase=passphrase)

    # derive the master key from the seed bytes
    master_private_key, master_chain_code = derive_master_key(seed_bytes)

    # derive the child key from the master key, given the specified path
    return derive_child_key(master_private_key, master_chain_code, path)


def entropy_to_mnemonic(entropy: bytes) -> str:
    """
    Convert entropy bytes to a mnemonic phrase.

    :param entropy: bytes The entropy bytes.
    :return: str The generated mnemonic phrase.

    :raises ValueError: If the data length is invalid.
    """
    # Get the english mnemonic words list - later we can add support for other languages
    mnemonic = ENGLISH_MNEMONIC_WORDS_LIST

    if len(entropy) not in [16, 20, 24, 28, 32]:
        raise ValueError(
            f"Data length should be one of the following: [16, 20, 24, 28, 32], but it is not ({len(entropy)})."
        )

    # b is the binary representation of the entropy joined with the first bits of the hash
    h = sha256(entropy).hex()
    b = (
        bin(int.from_bytes(entropy, byteorder="big"))[2:].zfill(len(entropy) * 8)
        + bin(int(h, 16))[2:].zfill(256)[: len(entropy) * 8 // 32]
    )

    # Iterate over the binary string taking 11 bits for each word
    result = []
    for i in range(len(b) // 11):
        idx = int(b[i * 11 : (i + 1) * 11], 2)  # noqa: E203
        result.append(mnemonic[idx])

    return " ".join(result)


def generate_entropy(num_bits: int) -> bytes:
    """
    Generate entropy bytes.

    :param num_bits: int The number of bits for the entropy.

    :return: bytes The generated entropy bytes.
    """
    byte_length = (num_bits + 7) // 8
    entropy = os.urandom(byte_length)
    return entropy


def generate_mnemonic(num_bits=256):
    """
    Generate a mnemonic phrase.

    :param num_bits: int The number of bits for the entropy.

    :return: str The generated mnemonic phrase.
    """
    entropy = generate_entropy(num_bits)
    return entropy_to_mnemonic(entropy)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommitInfo(_message.Message):
    __slots__ = ("version", "store_infos")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    STORE_INFOS_FIELD_NUMBER: _ClassVar[int]
    version: int
    store_infos: _containers.RepeatedCompositeFieldContainer[StoreInfo]
    def __init__(self, version: _Optional[int] = ..., store_infos: _Optional[_Iterable[_Union[StoreInfo, _Mapping]]] = ...) -> None: ...

class StoreInfo(_message.Message):
    __slots__ = ("name", "commit_id")
    NAME_FIELD_NUMBER: _ClassVar[int]
    COMMIT_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    commit_id: CommitID
    def __init__(self, name: _Optional[str] = ..., commit_id: _Optional[_Union[CommitID, _Mapping]] = ...) -> None: ...

class CommitID(_message.Message):
    __slots__ = ("version", "hash")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    version: int
    hash: bytes
    def __init__(self, version: _Optional[int] = ..., hash: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/tx/v1beta1/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/tx/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.crypto.multisig.v1beta1 import multisig_pb2 as cosmos_dot_crypto_dot_multisig_dot_v1beta1_dot_multisig__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.tx.signing.v1beta1 import signing_pb2 as cosmos_dot_tx_dot_signing_dot_v1beta1_dot_signing__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmos/tx/v1beta1/tx.proto\x12\x11\x63osmos.tx.v1beta1\x1a\x14gogoproto/gogo.proto\x1a-cosmos/crypto/multisig/v1beta1/multisig.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\'cosmos/tx/signing/v1beta1/signing.proto\x1a\x19google/protobuf/any.proto\"q\n\x02Tx\x12\'\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x19.cosmos.tx.v1beta1.TxBody\x12.\n\tauth_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.AuthInfo\x12\x12\n\nsignatures\x18\x03 \x03(\x0c\"H\n\x05TxRaw\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c\"`\n\x07SignDoc\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0c\x12\x10\n\x08\x63hain_id\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04\"\xc7\x01\n\x06TxBody\x12&\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04memo\x18\x02 \x01(\t\x12\x16\n\x0etimeout_height\x18\x03 \x01(\x04\x12\x30\n\x11\x65xtension_options\x18\xff\x07 \x03(\x0b\x32\x14.google.protobuf.Any\x12=\n\x1enon_critical_extension_options\x18\xff\x0f \x03(\x0b\x32\x14.google.protobuf.Any\"d\n\x08\x41uthInfo\x12\x33\n\x0csigner_infos\x18\x01 \x03(\x0b\x32\x1d.cosmos.tx.v1beta1.SignerInfo\x12#\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.Fee\"x\n\nSignerInfo\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12.\n\tmode_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.ModeInfo\x12\x10\n\x08sequence\x18\x03 \x01(\x04\"\xb5\x02\n\x08ModeInfo\x12\x34\n\x06single\x18\x01 \x01(\x0b\x32\".cosmos.tx.v1beta1.ModeInfo.SingleH\x00\x12\x32\n\x05multi\x18\x02 \x01(\x0b\x32!.cosmos.tx.v1beta1.ModeInfo.MultiH\x00\x1a;\n\x06Single\x12\x31\n\x04mode\x18\x01 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignMode\x1a{\n\x05Multi\x12\x41\n\x08\x62itarray\x18\x01 \x01(\x0b\x32/.cosmos.crypto.multisig.v1beta1.CompactBitArray\x12/\n\nmode_infos\x18\x02 \x03(\x0b\x32\x1b.cosmos.tx.v1beta1.ModeInfoB\x05\n\x03sum\"\x95\x01\n\x03\x46\x65\x65\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\r\n\x05payer\x18\x03 \x01(\t\x12\x0f\n\x07granter\x18\x04 \x01(\tB\'Z%github.com/cosmos/cosmos-sdk/types/txb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/tx'
  _globals['_FEE'].fields_by_name['amount']._loaded_options = None
  _globals['_FEE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_TX']._serialized_start=218
  _globals['_TX']._serialized_end=331
  _globals['_TXRAW']._serialized_start=333
  _globals['_TXRAW']._serialized_end=405
  _globals['_SIGNDOC']._serialized_start=407
  _globals['_SIGNDOC']._serialized_end=503
  _globals['_TXBODY']._serialized_start=506
  _globals['_TXBODY']._serialized_end=705
  _globals['_AUTHINFO']._serialized_start=707
  _globals['_AUTHINFO']._serialized_end=807
  _globals['_SIGNERINFO']._serialized_start=809
  _globals['_SIGNERINFO']._serialized_end=929
  _globals['_MODEINFO']._serialized_start=932
  _globals['_MODEINFO']._serialized_end=1241
  _globals['_MODEINFO_SINGLE']._serialized_start=1050
  _globals['_MODEINFO_SINGLE']._serialized_end=1109
  _globals['_MODEINFO_MULTI']._serialized_start=1111
  _globals['_MODEINFO_MULTI']._serialized_end=1234
  _globals['_FEE']._serialized_start=1244
  _globals['_FEE']._serialized_end=1393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proofs.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proofs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cproofs.proto\x12\x05ics23\"g\n\x0e\x45xistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x1b\n\x04leaf\x18\x03 \x01(\x0b\x32\r.ics23.LeafOp\x12\x1c\n\x04path\x18\x04 \x03(\x0b\x32\x0e.ics23.InnerOp\"k\n\x11NonExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12#\n\x04left\x18\x02 \x01(\x0b\x32\x15.ics23.ExistenceProof\x12$\n\x05right\x18\x03 \x01(\x0b\x32\x15.ics23.ExistenceProof\"\xc7\x01\n\x0f\x43ommitmentProof\x12&\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x15.ics23.ExistenceProofH\x00\x12,\n\x08nonexist\x18\x02 \x01(\x0b\x32\x18.ics23.NonExistenceProofH\x00\x12\"\n\x05\x62\x61tch\x18\x03 \x01(\x0b\x32\x11.ics23.BatchProofH\x00\x12\x31\n\ncompressed\x18\x04 \x01(\x0b\x32\x1b.ics23.CompressedBatchProofH\x00\x42\x07\n\x05proof\"\xa0\x01\n\x06LeafOp\x12\x1b\n\x04hash\x18\x01 \x01(\x0e\x32\r.ics23.HashOp\x12\"\n\x0bprehash_key\x18\x02 \x01(\x0e\x32\r.ics23.HashOp\x12$\n\rprehash_value\x18\x03 \x01(\x0e\x32\r.ics23.HashOp\x12\x1f\n\x06length\x18\x04 \x01(\x0e\x32\x0f.ics23.LengthOp\x12\x0e\n\x06prefix\x18\x05 \x01(\x0c\"F\n\x07InnerOp\x12\x1b\n\x04hash\x18\x01 \x01(\x0e\x32\r.ics23.HashOp\x12\x0e\n\x06prefix\x18\x02 \x01(\x0c\x12\x0e\n\x06suffix\x18\x03 \x01(\x0c\"y\n\tProofSpec\x12 \n\tleaf_spec\x18\x01 \x01(\x0b\x32\r.ics23.LeafOp\x12$\n\ninner_spec\x18\x02 \x01(\x0b\x32\x10.ics23.InnerSpec\x12\x11\n\tmax_depth\x18\x03 \x01(\x05\x12\x11\n\tmin_depth\x18\x04 \x01(\x05\"\x9c\x01\n\tInnerSpec\x12\x13\n\x0b\x63hild_order\x18\x01 \x03(\x05\x12\x12\n\nchild_size\x18\x02 \x01(\x05\x12\x19\n\x11min_prefix_length\x18\x03 \x01(\x05\x12\x19\n\x11max_prefix_length\x18\x04 \x01(\x05\x12\x13\n\x0b\x65mpty_child\x18\x05 \x01(\x0c\x12\x1b\n\x04hash\x18\x06 \x01(\x0e\x32\r.ics23.HashOp\"0\n\nBatchProof\x12\"\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.ics23.BatchEntry\"k\n\nBatchEntry\x12&\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x15.ics23.ExistenceProofH\x00\x12,\n\x08nonexist\x18\x02 \x01(\x0b\x32\x18.ics23.NonExistenceProofH\x00\x42\x07\n\x05proof\"k\n\x14\x43ompressedBatchProof\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.ics23.CompressedBatchEntry\x12%\n\rlookup_inners\x18\x02 \x03(\x0b\x32\x0e.ics23.InnerOp\"\x89\x01\n\x14\x43ompressedBatchEntry\x12\x30\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x1f.ics23.CompressedExistenceProofH\x00\x12\x36\n\x08nonexist\x18\x02 \x01(\x0b\x32\".ics23.CompressedNonExistenceProofH\x00\x42\x07\n\x05proof\"a\n\x18\x43ompressedExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x1b\n\x04leaf\x18\x03 \x01(\x0b\x32\r.ics23.LeafOp\x12\x0c\n\x04path\x18\x04 \x03(\x05\"\x89\x01\n\x1b\x43ompressedNonExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12-\n\x04left\x18\x02 \x01(\x0b\x32\x1f.ics23.CompressedExistenceProof\x12.\n\x05right\x18\x03 \x01(\x0b\x32\x1f.ics23.CompressedExistenceProof*U\n\x06HashOp\x12\x0b\n\x07NO_HASH\x10\x00\x12\n\n\x06SHA256\x10\x01\x12\n\n\x06SHA512\x10\x02\x12\n\n\x06KECCAK\x10\x03\x12\r\n\tRIPEMD160\x10\x04\x12\x0b\n\x07\x42ITCOIN\x10\x05*\xab\x01\n\x08LengthOp\x12\r\n\tNO_PREFIX\x10\x00\x12\r\n\tVAR_PROTO\x10\x01\x12\x0b\n\x07VAR_RLP\x10\x02\x12\x0f\n\x0b\x46IXED32_BIG\x10\x03\x12\x12\n\x0e\x46IXED32_LITTLE\x10\x04\x12\x0f\n\x0b\x46IXED64_BIG\x10\x05\x12\x12\n\x0e\x46IXED64_LITTLE\x10\x06\x12\x14\n\x10REQUIRE_32_BYTES\x10\x07\x12\x14\n\x10REQUIRE_64_BYTES\x10\x08\x42\x1cZ\x1agithub.com/confio/ics23/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proofs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\032github.com/confio/ics23/go'
  _globals['_HASHOP']._serialized_start=1603
  _globals['_HASHOP']._serialized_end=1688
  _globals['_LENGTHOP']._serialized_start=1691
  _globals['_LENGTHOP']._serialized_end=1862
  _globals['_EXISTENCEPROOF']._serialized_start=23
  _globals['_EXISTENCEPROOF']._serialized_end=126
  _globals['_NONEXISTENCEPROOF']._serialized_start=128
  _globals['_NONEXISTENCEPROOF']._serialized_end=235
  _globals['_COMMITMENTPROOF']._serialized_start=238
  _globals['_COMMITMENTPROOF']._serialized_end=437
  _globals['_LEAFOP']._serialized_start=440
  _globals['_LEAFOP']._serialized_end=600
  _globals['_INNEROP']._serialized_start=602
  _globals['_INNEROP']._serialized_end=672
  _globals['_PROOFSPEC']._serialized_start=674
  _globals['_PROOFSPEC']._serialized_end=795
  _globals['_INNERSPEC']._serialized_start=798
  _globals['_INNERSPEC']._serialized_end=954
  _globals['_BATCHPROOF']._serialized_start=956
  _globals['_BATCHPROOF']._serialized_end=1004
  _globals['_BATCHENTRY']._serialized_start=1006
  _globals['_BATCHENTRY']._serialized_end=1113
  _globals['_COMPRESSEDBATCHPROOF']._serialized_start=1115
  _globals['_COMPRESSEDBATCHPROOF']._serialized_end=1222
  _globals['_COMPRESSEDBATCHENTRY']._serialized_start=1225
  _globals['_COMPRESSEDBATCHENTRY']._serialized_end=1362
  _globals['_COMPRESSEDEXISTENCEPROOF']._serialized_start=1364
  _globals['_COMPRESSEDEXISTENCEPROOF']._serialized_end=1461
  _globals['_COMPRESSEDNONEXISTENCEPROOF']._serialized_start=1464
  _globals['_COMPRESSEDNONEXISTENCEPROOF']._serialized_end=1601
# @@protoc_insertion_point(module_scope)



from collections import UserString
from typing import Optional, Union

import bech32

from neurionpy.crypto.hashfuncs import ripemd160, sha256
from neurionpy.crypto.keypairs import PublicKey


DEFAULT_PREFIX = "neurion"


def _to_bech32(prefix: str, data: bytes) -> str:
    data_base5 = bech32.convertbits(data, 8, 5, True)
    if data_base5 is None:
        raise RuntimeError("Unable to parse address")  # pragma: no cover
    return bech32.bech32_encode(prefix, data_base5)


class Address(UserString):
    """Address class."""

    def __init__(
        self,
        value: Union[str, bytes, PublicKey, "Address"],
        prefix: Optional[str] = None,
    ):
        """Initialize Address instance.

        :param value: str, byte, public key or Address another instance
        :param prefix: optional string
        :raises RuntimeError: Unable to parse address
        :raises RuntimeError: Incorrect address length
        :raises TypeError: Unexpected type of `value` parameter
        """
        # pylint: disable=super-init-not-called
        if prefix is None:
            prefix = DEFAULT_PREFIX

        if isinstance(value, str):
            _, data_base5 = bech32.bech32_decode(value)
            if data_base5 is None:
                raise RuntimeError("Unable to parse address")

            data_base8 = bech32.convertbits(data_base5, 5, 8, False)
            if data_base8 is None:
                raise RuntimeError("Unable to parse address")  # pragma: no cover

            self._address = bytes(data_base8)
            self._display = value

        elif isinstance(value, bytes):
            if len(value) != 20:
                raise RuntimeError("Incorrect address length")

            self._address = value
            self._display = _to_bech32(prefix, self._address)

        elif isinstance(value, PublicKey):
            self._address = ripemd160(sha256(value.public_key_bytes))
            self._display = _to_bech32(prefix, self._address)

        elif isinstance(value, Address):
            self._address = value._address
            # prefix might be different from the original Address, so we need to reencode it here.
            self._display = _to_bech32(prefix, self._address)
        else:
            raise TypeError("Unexpected type of `value` parameter")  # pragma: no cover

    def __str__(self):
        """String representation of the address."""  # noqa: D401
        return self._display

    def __bytes__(self):
        """bytes representation of the address."""
        return self._address

    @property
    def data(self):  # noqa:
        """Return address in string."""
        return str(self)

    def __json__(self):  # noqa:
        return str(self)



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PathwayUser(_message.Message):
    __slots__ = ("id", "user")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    id: int
    user: str
    def __init__(self, id: _Optional[int] = ..., user: _Optional[str] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    STATE_UNINITIALIZED_UNSPECIFIED: _ClassVar[State]
    STATE_INIT: _ClassVar[State]
    STATE_TRYOPEN: _ClassVar[State]
    STATE_OPEN: _ClassVar[State]
    STATE_CLOSED: _ClassVar[State]

class Order(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ORDER_NONE_UNSPECIFIED: _ClassVar[Order]
    ORDER_UNORDERED: _ClassVar[Order]
    ORDER_ORDERED: _ClassVar[Order]
STATE_UNINITIALIZED_UNSPECIFIED: State
STATE_INIT: State
STATE_TRYOPEN: State
STATE_OPEN: State
STATE_CLOSED: State
ORDER_NONE_UNSPECIFIED: Order
ORDER_UNORDERED: Order
ORDER_ORDERED: Order

class Channel(_message.Message):
    __slots__ = ("state", "ordering", "counterparty", "connection_hops", "version")
    STATE_FIELD_NUMBER: _ClassVar[int]
    ORDERING_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_HOPS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    state: State
    ordering: Order
    counterparty: Counterparty
    connection_hops: _containers.RepeatedScalarFieldContainer[str]
    version: str
    def __init__(self, state: _Optional[_Union[State, str]] = ..., ordering: _Optional[_Union[Order, str]] = ..., counterparty: _Optional[_Union[Counterparty, _Mapping]] = ..., connection_hops: _Optional[_Iterable[str]] = ..., version: _Optional[str] = ...) -> None: ...

class IdentifiedChannel(_message.Message):
    __slots__ = ("state", "ordering", "counterparty", "connection_hops", "version", "port_id", "channel_id")
    STATE_FIELD_NUMBER: _ClassVar[int]
    ORDERING_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_HOPS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    state: State
    ordering: Order
    counterparty: Counterparty
    connection_hops: _containers.RepeatedScalarFieldContainer[str]
    version: str
    port_id: str
    channel_id: str
    def __init__(self, state: _Optional[_Union[State, str]] = ..., ordering: _Optional[_Union[Order, str]] = ..., counterparty: _Optional[_Union[Counterparty, _Mapping]] = ..., connection_hops: _Optional[_Iterable[str]] = ..., version: _Optional[str] = ..., port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class Counterparty(_message.Message):
    __slots__ = ("port_id", "channel_id")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class Packet(_message.Message):
    __slots__ = ("sequence", "source_port", "source_channel", "destination_port", "destination_channel", "data", "timeout_height", "timeout_timestamp")
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PORT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_PORT_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    sequence: int
    source_port: str
    source_channel: str
    destination_port: str
    destination_channel: str
    data: bytes
    timeout_height: _client_pb2.Height
    timeout_timestamp: int
    def __init__(self, sequence: _Optional[int] = ..., source_port: _Optional[str] = ..., source_channel: _Optional[str] = ..., destination_port: _Optional[str] = ..., destination_channel: _Optional[str] = ..., data: _Optional[bytes] = ..., timeout_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., timeout_timestamp: _Optional[int] = ...) -> None: ...

class PacketState(_message.Message):
    __slots__ = ("port_id", "channel_id", "sequence", "data")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    sequence: int
    data: bytes
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., sequence: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class Acknowledgement(_message.Message):
    __slots__ = ("result", "error")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    result: bytes
    error: str
    def __init__(self, result: _Optional[bytes] = ..., error: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/privval/v1beta2/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/privval/v1beta2/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.crypto.v1 import keys_pb2 as cometbft_dot_crypto_dot_v1_dot_keys__pb2
from cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cometbft/privval/v1beta2/types.proto\x12\x18\x63ometbft.privval.v1beta2\x1a\x1d\x63ometbft/crypto/v1/keys.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x14gogoproto/gogo.proto\"6\n\x11RemoteSignerError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"!\n\rPubKeyRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\"\x82\x01\n\x0ePubKeyResponse\x12\x34\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1d.cometbft.crypto.v1.PublicKeyB\x04\xc8\xde\x1f\x00\x12:\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerError\"J\n\x0fSignVoteRequest\x12%\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.Vote\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"}\n\x12SignedVoteResponse\x12+\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteB\x04\xc8\xde\x1f\x00\x12:\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerError\"V\n\x13SignProposalRequest\x12-\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.Proposal\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"\x89\x01\n\x16SignedProposalResponse\x12\x33\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalB\x04\xc8\xde\x1f\x00\x12:\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerError\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xd6\x04\n\x07Message\x12\x42\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32\'.cometbft.privval.v1beta2.PubKeyRequestH\x00\x12\x44\n\x10pub_key_response\x18\x02 \x01(\x0b\x32(.cometbft.privval.v1beta2.PubKeyResponseH\x00\x12\x46\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32).cometbft.privval.v1beta2.SignVoteRequestH\x00\x12L\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32,.cometbft.privval.v1beta2.SignedVoteResponseH\x00\x12N\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32-.cometbft.privval.v1beta2.SignProposalRequestH\x00\x12T\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32\x30.cometbft.privval.v1beta2.SignedProposalResponseH\x00\x12=\n\x0cping_request\x18\x07 \x01(\x0b\x32%.cometbft.privval.v1beta2.PingRequestH\x00\x12?\n\rping_response\x18\x08 \x01(\x0b\x32&.cometbft.privval.v1beta2.PingResponseH\x00\x42\x05\n\x03sum*\xa8\x01\n\x06\x45rrors\x12\x12\n\x0e\x45RRORS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x45RRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14\x45RRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19\x45RRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13\x45RRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14\x45RRORS_WRITE_TIMEOUT\x10\x05\x42;Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.privval.v1beta2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta2'
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._loaded_options = None
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._loaded_options = None
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_ERRORS']._serialized_start=1438
  _globals['_ERRORS']._serialized_end=1606
  _globals['_REMOTESIGNERERROR']._serialized_start=150
  _globals['_REMOTESIGNERERROR']._serialized_end=204
  _globals['_PUBKEYREQUEST']._serialized_start=206
  _globals['_PUBKEYREQUEST']._serialized_end=239
  _globals['_PUBKEYRESPONSE']._serialized_start=242
  _globals['_PUBKEYRESPONSE']._serialized_end=372
  _globals['_SIGNVOTEREQUEST']._serialized_start=374
  _globals['_SIGNVOTEREQUEST']._serialized_end=448
  _globals['_SIGNEDVOTERESPONSE']._serialized_start=450
  _globals['_SIGNEDVOTERESPONSE']._serialized_end=575
  _globals['_SIGNPROPOSALREQUEST']._serialized_start=577
  _globals['_SIGNPROPOSALREQUEST']._serialized_end=663
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_start=666
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_end=803
  _globals['_PINGREQUEST']._serialized_start=805
  _globals['_PINGREQUEST']._serialized_end=818
  _globals['_PINGRESPONSE']._serialized_start=820
  _globals['_PINGRESPONSE']._serialized_end=834
  _globals['_MESSAGE']._serialized_start=837
  _globals['_MESSAGE']._serialized_end=1435
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.auth.v1beta1.query_pb2 import (
    QueryAccountRequest,
    QueryAccountResponse,
    QueryParamsRequest,
    QueryParamsResponse,
)


class Auth(ABC):
    """Auth abstract class."""

    @abstractmethod
    def Account(self, request: QueryAccountRequest) -> QueryAccountResponse:
        """
        Query account data - sequence, account_id, etc.

        :param request: QueryAccountRequest that contains account address

        :return: QueryAccountResponse
        """

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query all parameters.

        :param request: QueryParamsRequest

        :return: QueryParamsResponse
        """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/plagiarism_report.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/plagiarism_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(neurion/crucible/plagiarism_report.proto\x12\x10neurion.crucible\"\xe3\x02\n\x10PlagiarismReport\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x1c\n\x14\x63opied_submission_id\x18\x03 \x01(\x04\x12\x1f\n\x17suspected_submission_id\x18\x04 \x01(\x04\x12\x12\n\narbitrator\x18\x05 \x01(\t\x12\x38\n\x06result\x18\x06 \x01(\x0e\x32(.neurion.crucible.PlagiarismReportResult\x12\x19\n\x11\x63reated_timestamp\x18\x07 \x01(\x04\x12\x1a\n\x12\x64\x65\x63ision_timestamp\x18\x08 \x01(\x04\x12\x1b\n\x13proof_of_plagiarism\x18\t \x01(\t\x12\x1c\n\x14reason_for_rejection\x18\n \x01(\t\x12\x0f\n\x07\x64\x65posit\x18\x0c \x01(\x04\x12\x10\n\x08reporter\x18\r \x01(\t\x12\x10\n\x08reportee\x18\x0e \x01(\t*\x92\x01\n\x16PlagiarismReportResult\x12*\n&PLAGIARISM_REPORT_RESULT_NOT_AVAILABLE\x10\x00\x12%\n!PLAGIARISM_REPORT_RESULT_ACCEPTED\x10\x01\x12%\n!PLAGIARISM_REPORT_RESULT_REJECTED\x10\x02\x42\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.plagiarism_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_PLAGIARISMREPORTRESULT']._serialized_start=421
  _globals['_PLAGIARISMREPORTRESULT']._serialized_end=567
  _globals['_PLAGIARISMREPORT']._serialized_start=63
  _globals['_PLAGIARISMREPORT']._serialized_end=418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/authz/v1beta1/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/authz/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/authz/v1beta1/tx.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a cosmos/authz/v1beta1/authz.proto\"^\n\x08MsgGrant\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x30\n\x05grant\x18\x03 \x01(\x0b\x32\x1b.cosmos.authz.v1beta1.GrantB\x04\xc8\xde\x1f\x00\"\"\n\x0fMsgExecResponse\x12\x0f\n\x07results\x18\x01 \x03(\x0c\"`\n\x07MsgExec\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12\x44\n\x04msgs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB \xca\xb4-\x1csdk.Msg, authz.Authorization\"\x12\n\x10MsgGrantResponse\"C\n\tMsgRevoke\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t\"\x13\n\x11MsgRevokeResponse2\xf8\x01\n\x03Msg\x12O\n\x05Grant\x12\x1e.cosmos.authz.v1beta1.MsgGrant\x1a&.cosmos.authz.v1beta1.MsgGrantResponse\x12L\n\x04\x45xec\x12\x1d.cosmos.authz.v1beta1.MsgExec\x1a%.cosmos.authz.v1beta1.MsgExecResponse\x12R\n\x06Revoke\x12\x1f.cosmos.authz.v1beta1.MsgRevoke\x1a\'.cosmos.authz.v1beta1.MsgRevokeResponseB*Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz\310\341\036\000'
  _globals['_MSGGRANT'].fields_by_name['grant']._loaded_options = None
  _globals['_MSGGRANT'].fields_by_name['grant']._serialized_options = b'\310\336\037\000'
  _globals['_MSGEXEC'].fields_by_name['msgs']._loaded_options = None
  _globals['_MSGEXEC'].fields_by_name['msgs']._serialized_options = b'\312\264-\034sdk.Msg, authz.Authorization'
  _globals['_MSGGRANT']._serialized_start=235
  _globals['_MSGGRANT']._serialized_end=329
  _globals['_MSGEXECRESPONSE']._serialized_start=331
  _globals['_MSGEXECRESPONSE']._serialized_end=365
  _globals['_MSGEXEC']._serialized_start=367
  _globals['_MSGEXEC']._serialized_end=463
  _globals['_MSGGRANTRESPONSE']._serialized_start=465
  _globals['_MSGGRANTRESPONSE']._serialized_end=483
  _globals['_MSGREVOKE']._serialized_start=485
  _globals['_MSGREVOKE']._serialized_end=552
  _globals['_MSGREVOKERESPONSE']._serialized_start=554
  _globals['_MSGREVOKERESPONSE']._serialized_end=573
  _globals['_MSG']._serialized_start=576
  _globals['_MSG']._serialized_end=824
# @@protoc_insertion_point(module_scope)
